import 'package:flutter/material.dart';

void main() {
  runApp(const MainPage());
}

class MainPage extends StatelessWidget {

  const MainPage({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Todo App',
      theme: ThemeData(
        useMaterial3: false,  // Material 3を無効にする
      ),
      home: TextInputWidget(),
    );
  }
}

class TextInputWidget extends StatefulWidget {

  const TextInputWidget({super.key});

  @override
  State<TextInputWidget> createState() => _TextInputWidgetState();
}

class _TextInputWidgetState extends State<TextInputWidget> {
  final _controller = TextEditingController();
  List<String> todoList = [];

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: const Color.fromRGBO(165, 190, 215, 1.0),
      appBar: AppBar(
        title: const Text('Todo App'),
      ),
      body: ListView.builder(
        itemCount: todoList.length + 1,
        itemBuilder: (BuildContext context, int index) {
          if (index == todoList.length) {  // リスト一覧の最後のindexにTextFieldを作成
            return _createTextArea();
          } else {                         // それ以外はTodoカードを作成
            var title = todoList[index];
            return _createTodoCard(title, index);
          }
        },
      ),
    );
  }

  @override
  void dispose() {
    super.dispose();
    _controller.dispose();
  }

  Widget _createTodoCard(String title, int index) {
    return Card(
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(10.0),
        ),
        margin: const EdgeInsets.symmetric(horizontal: 10.0, vertical: 5.0),
        child: Column(
          mainAxisSize: MainAxisSize.max,
          children: [
            ListTile(title: Text(title)),
            Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                ElevatedButton(
                    onPressed: () {
                      // 完了したときの処理
                      _complete(index);
                    },
                    child: const Text('完了')),
                const SizedBox(
                  width: 10.0,
                ),
                ElevatedButton(
                    onPressed: () {
                      // 削除したときの処理
                      _delete(index);
                    },
                    child: const Text('削除')),
                const SizedBox(
                  width: 10.0,
                )
              ],
            )
          ],
        )
    );
  }

  Widget _createTextArea() {
    return Card(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(10.0),
      ),
      margin: const EdgeInsets.symmetric(horizontal: 10.0, vertical: 5.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 10.0),
            child: TextField(
              controller: _controller,
              decoration: const InputDecoration(hintText: '入力してください'),
              onChanged: (String value) {
                print(value);
              },
              onSubmitted: _submitTodo,
            ),
          ),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 10.0, vertical: 5.0),
            child: ElevatedButton(
                onPressed: () {
                  // カードを追加するをタップしたときの処理
                  _submitTodo(_controller.text);
                },
                child: const Text('カードを追加する')),
          )
        ],
      ),
    );
  }

  void _submitTodo(String title) {
    setState(() {
      if (title.isEmpty == false) {
        todoList.add(title);
        _controller.clear();
      }
    });
  }

  void _complete(int index) {
    setState(() {
      todoList.removeAt(index);
    });
  }

  void _delete(int index) {
    setState(() {
      todoList.removeAt(index);
    });
  }
}